/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.util.custom.base;

import static com.openexchange.util.custom.base.NullUtil.immutableCopyOf;
import java.util.Collection;


import com.google.common.collect.ImmutableList;
import com.openexchange.annotation.Nullable;

public final class ChainPlaceholderResolver implements PlaceholderResolver {
    
    private final ImmutableList<PlaceholderResolver> chain;

    public ChainPlaceholderResolver(final Collection<PlaceholderResolver> chain) {
        super();
        this.chain = immutableCopyOf(chain);
    }

    public ChainPlaceholderResolver(PlaceholderResolver... chain) {
        super();
        this.chain = immutableCopyOf(chain);
    }
    
    @Override
    public @Nullable String resolve(String placeholder) throws Exception {
        for (final PlaceholderResolver resolver : chain) {
            final String result = resolver.resolve(placeholder);
            if (result != null) {
                return result;
            }
        }
        return null;
   }
    
}
